/*****************************************************************/
/* FILE:        	w2indvars.sas                            */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Angela Merrill/Tiago Ribeiro             */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Code Wave 2 respondent level vars        */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
%global thisfile;
%let lastfile=&thisfile;
%let thisfile=w2indvars;
proc printto log="&thisfile..log" print="&thisfile..lst" new; run;


%include "~/ribeiro/datagen/header.inc";
options ps=2000 ls=150;

   
%macro h;
 
x zcat "&rawc2/a95pr_r.ssd01.Z" > "&local/a95pr_r.ssd01";
x zcat "&rawc2/a95cs_r.ssd01.Z" > "&local/a95cs_r.ssd01";
x zcat "&rawc2/a95a_r.ssd01.Z"  > "&local/a95a_r.ssd01";
x zcat "&rawc2/a95b_r.ssd01.Z"  > "&local/a95b_r.ssd01";
x zcat "&rawc2/a95c_r.ssd01.Z"  > "&local/a95c_r.ssd01";
x zcat "&rawc2/a95pc_r.ssd01.Z"  > "&local/a95pc_r.ssd01";
x zcat "&rawc2/a95d_r.ssd01.Z"  > "&local/a95d_r.ssd01";
x zcat "&rawc2/a95e_r.ssd01.Z"  > "&local/a95e_r.ssd01";
x zcat "&rawc2/a95g_r.ssd01.Z"  > "&local/a95g_r.ssd01";
x zcat "&rawc2/a95h_r.ssd01.Z"  > "&local/a95h_r.ssd01";
       
/*
proc contents data=local.a95pr_r;
proc contents data=local.a95cs_r;
proc contents data=local.a95a_r;
proc contents data=local.a95j_h;
proc contents data=local.a95f_h;
*/


/****************************/
/* Preload Variables        */  
/****************************/

data a95pr_r;
     set local.a95pr_r;
     hhidpn=hhid*1000+pn;

  /* Unfolding bracket randomization */
  /*     
         keep D169; *    W1 REALESTATE V1721;
         keep D170; *    W1 TRANSPORT V1725;
         keep D171; *    W1 BUSINESS V1730;
         keep D172; *    W1 IRA V1735;
         keep D173; *    W1 STOCKS V1744;
         keep D174; *    W1 CHECKINGS/SAVINGS V1750;
         keep D175; *    W1 CD  V1756;
         keep D176; *    W1 BONDS V1762;
         keep D179; *    W1 OWN RENT;
         keep D181; *    W1 OWN MORT V1112;
         keep D182; *    W1 IWN #OF IW IN HH;
         keep D184; *    LIVE ON FARM;
*/              
*         keep hhidpn ;
run;


/****************************/
/* Cover Screen Variables   */  
/****************************/

data a95cs_r;
     set local.a95cs_r;
     hhidpn=hhid*1000+pn;

/*
    keep hhidpn hhid dsubhh pn;
    
    keep D376; *   R FAM/NON V105;
    keep D377; *   R FIN/NON V106;
    famr2=d376;
    finr2=d377;
    
    keep D240; *    CS11.R-WHERE LIVE;
    keep D218; *    CS1A.PROXY/SELF INTERVIEW;
    keep D417; *    CS25.MONTH MOVED TO NURS HOME;
    keep D418; *    CS25.YEAR MOVED TO NURS HOME;
    keep D420; *    CS26.NURHM: STILL OWN/RENT HOME;
    keep D435; *    CS35A. ASSIGN 1 OR 2 RESIDENCE;
    keep D441; *    CS36C.R MOVED MAIN RESIDENCE;

    keep famr2 finr2 dfamr dfinr;
*/
    run;
/*
    proc freq; 
        tables 
            finr2*dfinr famr2*dfamr  / list missing; 
*/

data a95cs_r;
     set local.a95cs_r;
     hhidpn=hhid*1000+pn;
run;

data a95a_r;
     set local.a95a_r;
     hhidpn=hhid*1000+pn;
run;

data a95b_r;
     set local.a95b_r;
     hhidpn=hhid*1000+pn;
run;

data a95c_r;
     set local.a95c_r;
     hhidpn=hhid*1000+pn;
run;

data a95pc_r;
     set local.a95pc_r;
     hhidpn=hhid*1000+pn;
run;

data a95d_r;
     set local.a95d_r;
     hhidpn=hhid*1000+pn;
run;

data a95e_r;
     set local.a95e_r;
     hhidpn=hhid*1000+pn;
run;

data a95g_r;
     set local.a95g_r;
     hhidpn=hhid*1000+pn;
run;

data a95h_r;
     set local.a95h_r;
     hhidpn=hhid*1000+pn;
run;


%merge(w2ind0,a95cs_r,a95pr_r,hhidpn);
%merge(w2ind0,w2ind0,a95cs_r,hhidpn);
%merge(w2ind0,w2ind0,a95a_r,hhidpn);
%merge(w2ind0,w2ind0,a95b_r,hhidpn);
%merge(w2ind0,w2ind0,a95c_r,hhidpn);
%merge(w2ind0,w2ind0,a95pc_r,hhidpn);
%merge(w2ind0,w2ind0,a95d_r,hhidpn);
%merge(w2ind0,w2ind0,a95e_r,hhidpn);
%merge(w2ind0,w2ind0,a95g_r,hhidpn);
%merge(w2ind0,w2ind0,a95h_r,hhidpn);
    
data local.w2ind0;
    set w2ind0;
    run;

x /bin/rm "&local/a95pr_r.ssd01";
x /bin/rm "&local/a95cs_r.ssd01";
x /bin/rm "&local/a95a_r.ssd01";
x /bin/rm "&local/a95b_r.ssd01";
x /bin/rm "&local/a95c_r.ssd01";
x /bin/rm "&local/a95pc_r.ssd01";
x /bin/rm "&local/a95d_r.ssd01";
x /bin/rm "&local/a95e_r.ssd01";
x /bin/rm "&local/a95g_r.ssd01";
x /bin/rm "&local/a95h_r.ssd01";

%mend;
%h;


data w2ind0;
    set local.w2ind0;
    proxy2=d218;
run;
    
%vtic(w2ind0);

data w2ind0;
   set w2ind0;
   
   %include 'w2ind/demog2.sas';
   %include 'w2ind/health2.sas';
   %include 'w2ind/cogn2.sas';
   %include 'w2ind/parents2.sas';
   %include 'w2ind/adl_iadl2.sas';
   %include 'w2ind/work2.sas';
   %include 'w2ind/subprob2.sas';

run;

%vtoc(w2ind0,);


****************************************************;
* OUTPUT INDIVIDUAL-LEVEL DATASET;
****************************************************;
    
proc means nmiss n mean std min max;
    var %include "&thisfile..vars";;
run;

proc means nmiss n mean std min max;
    class proxy2;
    var %include "&thisfile..vars";;
run;

data local8.w2indvar;		
   set w2ind0;
   keep hhidpn;
   keep %include "&thisfile..vars";;
   run;
   
proc contents ;
proc means nmiss n mean std min max;
run;


   /****************************************************/ 
   /*****************End of File************************/ 
   /****************************************************/ 

   %let thisfile=&lastfile;
   proc printto log="&thisfile..log" print="&thisfile..lst"; run;

   /****************************************************/ 
   /****************************************************/ 
   /****************************************************/ 
