/*****************************************************************/
/* FILE:        	w3indvars.sas                            */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Angela Merrill/Tiago Ribeiro             */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Code Wave 3 respondent level vars        */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
%global thisfile;
%let lastfile=&thisfile;
%let thisfile=w3indvars;
proc printto log="&thisfile..log" print="&thisfile..lst" new; run;


%include "~/ribeiro/datagen/header.inc";
options ps=2000 ls=150;

 
%macro h;

x zcat "&rawc3/h98pr_r.ssd01.Z" > "&local/h98pr_r.ssd01";
x zcat "&rawc3/h98cs_r.ssd01.Z" > "&local/h98cs_r.ssd01";
x zcat "&rawc3/h98a_r.ssd01.Z"  > "&local/h98a_r.ssd01";
x zcat "&rawc3/h98b_r.ssd01.Z"  > "&local/h98b_r.ssd01";
x zcat "&rawc3/h98c_r.ssd01.Z"  > "&local/h98c_r.ssd01";
x zcat "&rawc3/h98pc_r.ssd01.Z" > "&local/h98pc_r.ssd01";
*x zcat "&rawc3/h98d_h.ssd01.Z"  > "&local/h98d_h.ssd01";
x zcat "&rawc3/h98e_r.ssd01.Z"  > "&local/h98e_r.ssd01";
x zcat "&rawc3/h98g_r.ssd01.Z"  > "&local/h98g_r.ssd01";
x zcat "&rawc3/h98h_r.ssd01.Z"  > "&local/h98h_r.ssd01";

*proc contents data=local.h98d_h;
    
/****************************/
/* Preload Variables        */  
/****************************/

data h98pr_r;
     set local.h98pr_r;
     hhidpn=hhid*1000+pn;
run;

data h98cs_r;
     set local.h98cs_r;
     hhidpn=hhid*1000+pn;
     cohort=f461; *ahead is f461=1;
run;
    
data h98a_r;
     set local.h98a_r;
     hhidpn=hhid*1000+pn;
run;

data h98b_r;
     set local.h98b_r;
     hhidpn=hhid*1000+pn;
run;

data h98c_r;
     set local.h98c_r;
     hhidpn=hhid*1000+pn;
run;

data h98pc_r;
     set local.h98pc_r;
     hhidpn=hhid*1000+pn;
run;

/*
data h98d_h;
     set local.h98d_h;
     hhidpn=hhid*1000+pn;
run;
*/
    
data h98e_r;
     set local.h98e_r;
     hhidpn=hhid*1000+pn;
run;

data h98g_r;
     set local.h98g_r;
     hhidpn=hhid*1000+pn;
run;

data h98h_r;
     set local.h98h_r;
     hhidpn=hhid*1000+pn;
run;

/* Get correction for heart varible - HEART ALERT*/
    libname heart "&base/ribeiro/datagen/ahead3/heart_alert";

    data heart_alert;
        set heart.heart_alert;
        hhidpn=hhid*1000+pn;
        drop hhid pn;
    run;
    

%merge(w3ind0,h98cs_r,h98pr_r,hhidpn);
%merge(w3ind0,w3ind0,h98cs_r,hhidpn);
%merge(w3ind0,w3ind0,h98a_r,hhidpn);
%merge(w3ind0,w3ind0,h98b_r,hhidpn);
%merge(w3ind0,w3ind0,h98c_r,hhidpn);
%merge(w3ind0,w3ind0,h98pc_r,hhidpn);
*%merge(w3ind0,w3ind0,h98d_h,hhidpn);
%merge(w3ind0,w3ind0,h98e_r,hhidpn);
%merge(w3ind0,w3ind0,h98g_r,hhidpn);
%merge(w3ind0,w3ind0,h98h_r,hhidpn);
%merge(w3ind0,w3ind0,heart_alert,hhidpn,1);
    
data local.w3ind0;
    set w3ind0;
    if cohort=1;
    drop cohort;
    run;

x /bin/rm "&local/h98pr_r.ssd01";
x /bin/rm "&local/h98cs_r.ssd01";
x /bin/rm "&local/h98a_r.ssd01";
x /bin/rm "&local/h98b_r.ssd01";
x /bin/rm "&local/h98c_r.ssd01";
x /bin/rm "&local/h98pc_r.ssd01";
*x /bin/rm "&local/h98d_h.ssd01";
x /bin/rm "&local/h98e_r.ssd01";
x /bin/rm "&local/h98g_r.ssd01";
x /bin/rm "&local/h98h_r.ssd01";

%mend;
%h;

data w3ind0;
set local.w3ind0;
proxy3=f483;
run;

%vtic(w3ind0);

data w3ind0;
set w3ind0;
   
   %include 'w3ind/demog3.sas';
   %include 'w3ind/health3.sas';
   %include 'w3ind/cogn3.sas';
   *%include 'w3ind/parents3.sas';
   %include 'w3ind/adl_iadl3.sas';
   %include 'w3ind/work3.sas';
   %include 'w3ind/subprob3.sas';

run;

%vtoc(w3ind0);

****************************************************;
* OUTPUT INDIVIDUAL-LEVEL DATASET;
****************************************************;
    
proc means nmiss n mean std min max;
    var %include "&thisfile..vars";;
run;

proc means nmiss n mean std min max;
    class proxy2;
    var %include "&thisfile..vars";;
run;

data local8.w3indvar;		
   set w3ind0;
   keep hhidpn;
   keep %include "&thisfile..vars";;
   run;
   
proc contents ;
proc means nmiss n mean std min max;
run;


   /****************************************************/ 
   /*****************End of File************************/ 
   /****************************************************/ 

   %let thisfile=&lastfile;
   proc printto log="&thisfile..log" print="&thisfile..lst"; run;

   /****************************************************/ 
   /****************************************************/ 
   /****************************************************/ 
