/*****************************************************************/
/* FILE:        	convertdata.sas                          */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Converts final dataset into TSP and SST  */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
*%include "~/ribeiro/datagen/header.inc";

data hww123;
    set local8.hww123;
run;

/***********************************************************/
/* convert data to SST                                     */        
/***********************************************************/

%macro exp_sst;    
proc export replace
    data=hww123    
    outfile="&local/hww123.dbf"
    dbms=dbf;
run;
 
        
/* 
SST label format 
label var[money] lab[change in M1 from year earlier]
*/

proc contents data=hww123 noprint out=hwwname(keep=name label);
data hwwname;
    set hwwname;
        name=lowcase(name);
        label=tranwrd(label,"#","num");
        file "sstlab.cmd";
        put @1 'label var[' @11 name @19 ']' @21 'lab[' @25 label ']';
run;

data _null_;
    file 'sstcode.cmd';
    put "config more[off]";
    put "config warning[off]";
    put "config echo[off]";
    put "spool off";
    put "load FILE[&local/hww123.dbf] dbase";
    put "run sstlab";
    put "save FILE[&local/hww123]";
    put "quit";
run;

x sst sstcode;
x /bin/rm sstcode.cmd;
x /bin/rm sstlab.cmd;
%mend;
%exp_sst;


/***********************************************************/
/* convert data to TSP                                     */        
/***********************************************************/

%macro exp_tsp;
proc export replace
    data=hww123    
    outfile="&local/hww123.dbf"
    dbms=dbf;
run;
    
    x /bin/rm/  &local/hww123.xls ;
    x dbmsnox &local/hww123.dbf &local/hww123.xls4;

    proc contents data=hww123 noprint out=hwwname(keep=name label);
    data hwwname;
        set hwwname;
        name=lowcase(name);
        label=tranwrd(label,"#","num");
        file "tsplab.tsp";
        put @1 'doc ' @5 name @14 "'" @15 label "';";
    run;
    
    data _null_;
        file 'tspcode.tsp';
        put 'options memory=200;';
        put 'smpl 1,6489;';
        put "out '" "&local/hww123" "';";
        put "read(file='" "&local/hww123.xls" "');";
        put "input 'tsplab.tsp';";
    run;

    x tsp tspcode.tsp ;

    x /bin/rm tspcode.tsp ;
    x /bin/rm tspcode.out ;
    x /bin/rm tsplab.tsp ;

    x /bin/rm/  &local/hww123.xls 

%mend;
%exp_tsp;








