/*****************************************************************/
/* FILE:        	hwwdata.sas                              */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Merge all wave respondent and asset data */
/* PROGRAM DESC:	Code final variables for analysis        */
/* PROGRAM DESC:	Output final dataset                     */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
%global thisfile;
%let thisfile=hwwdata;
proc printto log="&thisfile..log" print="&thisfile..lst" new; run;

%include "~/ribeiro/datagen/header.inc";
options ps=2000 ls=150;


%macro h;

   ****************************;
   ****************************;
   * GET WAVE 1 DATA;
   ****************************;
   ****************************;
       
data w1indvar;
   set local8.w1indvar;
   run;

    data tracker;
    set track.track;
    drop sage;
    label
        tdied2='Died - tracker file, w2'
        tdied3='Died - tracker file, w3'
        ;
    run;

data w2indvar;
   set local8.w2indvar;
   run;
   
data w2exit;
    set local8.w2exit;
    exitw2=1;
    label exitw2="in exit proxy interview";
run;

data w2indvar;
    set w2indvar w2exit;
    if exitw2=. then exitw2=0;
run;
proc sort data=w2indvar nodupkey;
    by hhidpn;
run;

data w3indvar;
       set local8.w3indvar; 
run;
       
data w3exit;
    set local8.w3exit;
    exitw3=1;
    label exitw3="in exit proxy interview w3";
run;

data w3indvar;
    set w3indvar w3exit;
    if exitw3 =. then exitw3=0;
run;
proc sort nodupkey; by hhidpn;

data allwv;
set tracker;
run;

%vtic(allwv);
    
%merge(allwv,allwv,w1indvar,hhidpn);
data allwv;set allwv; w1in=in2;
%merge(allwv,allwv,w2indvar,hhidpn);
data allwv;set allwv; w2in=in2;
%merge(allwv,allwv,w3indvar,hhidpn);

data allwv;
    set allwv;
    w3in=in2;
    ahead=(study in(11,12,13));
run;    


%let keep=
        AGEDIE2
        AGEDIE3
        AGEM1
        AGEM2
        AGEM3
        BIVIEWMO
        BIVIEWYR
        DIE2I
        DIVIEWMO
        DIVIEWYR
        FIVIEWMO
        FIVIEWYR
        MODIE2
        MODIE3
        MONTH12
        MONTH23
        MONTHD2
        MONTHD3
        MONTHS1
        MONTHS2
        MONTHS3
        TDIED2
        TDIED3
        YRDIE2
        YRDIE3
        r_m1
        r_m2
        r_m3
        r_m12
        r_m23
        r_md2
        r_md3
;
    
        data month;
            set local.monthdta;
            keep hhidpn &keep;
        run;
        data allwv;
            set allwv;
            drop &keep;
        run;
        
        %merge(allwv,allwv,month,hhidpn); 

%vtoc(allwv);

proc freq;
    tables
        w1in*inw1
        w2in*inw2
        w3in*inw3
        study*w1in*w2in*w3in
        / list missing ;
    
    
proc freq;
where ahead;
    tables
        w1in*inw1
        w2in*inw2
        w3in*inw3
        study*w1in*w2in*w3in
        / list missing ;
    
    
proc means nmiss n mean std min max;
    where ahead;
    var %include "&thisfile..vars";;
run;
    
proc means nmiss n mean std min max;
    where ahead and clean and eligible;
    var %include "&thisfile..vars";;
run;

proc means nmiss n mean std min max data=hww.hwwdata;
    where clean and eligible;
    var %include "&thisfile..vars";;
run;


    data local8.allwv;
    set allwv;
    if ahead; 
    run;
        
%mend;

%h;

data allwv;
    set local8.allwv;
    run;
    
%vtic(allwv);

proc freq;
    tables female*sex;
    tables sex*female1*female2*female3/ list missing;
run;


   /**********************************************************/
   /*   Code vars common to all waves and some demog vars    */ 
   /************* ********************************************/
   %include  'common_demog.sas';
   /**********************************************************/
   /**********************************************************/


   /**********************************************************/
   /*   Impute age mother and father died                    */ 
   /**********************************************************/
   %include 'impage.sas';
    
   %impage(p,allwv,tmp_p);
   %impage(m,allwv,tmp_m);

   data allwv;
       set allwv;
       drop pagedie magedie;
   run;

   %merge(allwv,allwv,tmp_p,hhidpn);
   %merge(allwv,allwv,tmp_m,hhidpn);
 
   proc datasets;
       modify allwv;
       rename
           magedie=magedie1
           pagedie=pagedie1;
   run;
   /**********************************************************/
   /**********************************************************/

       
   /**********************************************************/
   /*   Code BMI                                             */ 
   /**********************************************************/
    %include 'bmi.sas';
   /**********************************************************/
   /**********************************************************/

        
   /**********************************************************/
   /* Code cognition variable */
   /**********************************************************/
    %include 'cognition.sas';
  /**********************************************************/
   /**********************************************************/

       
   /**********************************************************/
   /* Impute very few obs from health vars                    */
   /**********************************************************/
    %include 'imp_health.sas';
   /**********************************************************/
   /**********************************************************/

   /**********************************************************/
   /*   Code prevalence and incidence variables              */ 
   /**********************************************************/
    %include 'prev_incid.sas';
   /**********************************************************/
   /**********************************************************/


   /**********************************************************/
   /*   Code number of diseases                              */ 
   /**********************************************************/
*   %include 'countdis.sas';
   /**********************************************************/
   /**********************************************************/

       
   /**********************************************************/
   /*   Code wealth data                                     */ 
   /**********************************************************/
   %include 'wealthdata.sas';
   %merge(allwv,allwv,wealth,hhidpn);
   /**********************************************************/
   /**********************************************************/


   /**********************************************************/
   /*   Code spouse variables                                */ 
   /**********************************************************/
    %include 'spouse.sas';
   /**********************************************************/
   /**********************************************************/


    %vtoc(allwv);

    
proc means nmiss n mean std min max;
    where ahead and clean and eligible;
    var %include "&thisfile..vars";;
run;

proc contents;
    
data local8.hwwdata;
   set allwv;
run;

%include 'finaldata.sas';

%include 'convertdata.sas';

endsas;



   /****************************************************/ 
   /*****************End of File************************/ 
   /****************************************************/ 

   %let thisfile=&lastfile;
   proc printto log="&thisfile..log" print="&thisfile..lst"; run;

   /****************************************************/ 
   /****************************************************/ 
   /****************************************************/ 



