/*****************************************************************/
/* FILE:        	impage.sas                               */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Angela Merrill/Tiago Ribeiro             */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Impute a few cases of age parents died   */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
%macro impage(v,din,dout);

data tmp;
 set &din;
 keep &v.agedie &v.alive &v.ageliv hhidpn;
 missdie=(&v.agedie=.); missliv=(&v.ageliv=.);
 keep missdie missliv;
run;

proc freq;
    tables missdie*&v.alive*missliv /missing list;
run;

data dono(keep=hhidpn &v.agedie) imp1 imp2;
    set tmp;
    if &v.agedie ne . then output dono;
    else do;
        if &v.ageliv eq . then output imp1;
        else if &v.ageliv ne . then output imp2;
        end;
run;
    
/* create donor dataset */
proc freq data=dono noprint;
    tables &v.agedie /out=donof(keep=percent &v.agedie);
run;
data donof(keep=&v.agedie cumpct rename=(cumpct=order)) donoff(keep=m cumpct);
    set donof;
    retain cumpct 0;
    cumpct=cumpct+percent/100;
    m=&v.agedie;
    output donof donoff;
    run;
                    
/* make sure age of death>age if alive */
data imp2;
    set imp2;
    m=&v.ageliv;
    run;
%merge(imp2,imp2,donoff,m,1);
proc sort data=imp2; by descending m;
data imp2;
    set imp2;
    retain h;
    if cumpct ne . then h=cumpct;
    else cumpct=h;
    drop h;
run;
data imp;
    set imp2 imp1;
    if cumpct=. then cumpct=0;
    rename cumpct=mimp;
    order=ranuni(123);
    order=cumpct+order*(1-cumpct);
    keep hhidpn order;
run;
data imp;
    set donof(in=in1) imp(in=in2);
    ind=in1;
    ini=in2;
    run;


    proc sort data=imp; by descending order;
data imp;
    set imp;
    retain h;
    if &v.agedie ne . then h=&v.agedie;
    else &v.agedie=h;
    if ini;
    drop h ini ind order;
    run;
    
    data &dout;
        set imp dono;
    run;
    
    proc means data=&din nmiss n mean std min max;
    var &v.agedie;
    proc means data=&dout nmiss n mean std min max;
    var &v.agedie;
%mend;
    
