/*****************************************************************/
/* FILE:        	prev_incid.sas                           */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Angela Merrill/Tiago Ribeiro             */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Code prevalence and incidence waves 1-3  */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/


   %macro prev(wv);

   if numadl&wv ne . then dadl&wv    = (numadl&wv>2);
   if numiadl&wv ne . then   diadl&wv   = (numiadl&wv>2);
   if hlth&wv ne . then   dhlth&wv   = (hlth&wv>3);
   if (proxyw&wv ne . and cogim&wv ne .) then cogprxy&wv = (proxyw&wv*cogim&wv);
   if numdrnk&wv ne . then   drnknow&wv = (numdrnk&wv>=3);

   if numadl&wv ne . then adl1_2&wv = (0  < numadl&wv & numadl&wv <=2);
   if numadl&wv ne . then adlgt3&wv = (numadl&wv >=3);
   if numiadl&wv ne . then iadl1_2&wv = (0 < numiadl&wv & numiadl&wv <=2);
   if numiadl&wv ne . then iadlgt3&wv = (numiadl&wv >=3);
  
   if bmi&wv ne . then lobmi&wv = max(0,20-bmi&wv);
   if bmi&wv ne . then hibmi&wv = max(0,bmi&wv-25);
   if bmi&wv ne . then bmilow&wv=(bmi&wv < 20);
   if bmi&wv ne . then bmihi&wv=(bmi&wv > 25);
   
   label
      dadl&wv    = "> 2 ADLs w&wv"
      diadl&wv   = "> 2 IADLs w&wv"
      dhlth&wv   = "hlth fair or poor (4,5) w&wv"
      cogprxy&wv = "cogim*proxy w&wv"
      drnknow&wv ="drink 3+/day w&wv"
      lobmi&wv   ="max(0,20-bmi) w&wv"
      hibmi&wv   ="max(0,bmi-25) w&wv"
      adl1_2&wv  ="1-2 ADLs w&wv"
      adlgt3&wv  ="> 3 ADLS w&wv"
      iadl1_2&wv ="1-2 IADLs w&wv"
      iadlgt3&wv ="> 3 IADLS w&wv"
      bmilow&wv  ="low bmi < 20, w&wv"
      bmihi&wv   ="high bmi > 25 w&wv"
      ;

%mend prev;

       
%macro incid(wv);
    %let wv0=%eval(&wv-1);   

    if (highbp&wv0 ne . & highbp&wv ne .) then  ihighbp&wv=(highbp&wv0=0 & highbp&wv=1);
    if (lung&wv0   ne . & lung&wv   ne .) then  ilung&wv  =(lung&wv0  =0 & lung&wv  =1);
    if (arthrt&wv0 ne . & arthrt&wv ne .) then  iarthrt&wv=(arthrt&wv0=0 & arthrt&wv=1);
    if (diabet&wv0 ne . & diabet&wv ne .) then  idiabet&wv=(diabet&wv0=0 & diabet&wv=1);
    if (cancer&wv0 ne . & cancer&wv ne .) then  icancer&wv=(cancer&wv0=0 & cancer&wv=1);
    if (heart&wv0  ne . & heart&wv  ne .) then  iheart&wv =(heart&wv0 =0 & heart&wv =1);
    if (stroke&wv0 ne . & stroke&wv ne .) then  istroke&wv=(stroke&wv0=0 & stroke&wv=1);
    if (psych&wv0  ne . & psych&wv  ne .) then  ipsych&wv =(psych&wv0 =0 & psych&wv =1);
    if (fall&wv0   ne . & fall&wv   ne .) then  ifall&wv  =(fall&wv0  =0 & fall&wv  =1);
    if (hipfrc&wv0 ne . & hipfrc&wv ne .) then  ihipfrc&wv=(hipfrc&wv0=0 & hipfrc&wv=1);
    if (incont&wv0 ne . & incont&wv ne .) then  iincont&wv=(incont&wv0=0 & incont&wv=1);
    if (cogn&wv0   ne . & cogn&wv   ne .) then  icogn&wv  =(cogn&wv0  =0 & cogn&wv  =1);
    if (depres&wv0 ne . & depres&wv ne .) then  idepres&wv=(depres&wv0=0 & depres&wv=1);
    if (dadl&wv0   ne . & dadl&wv   ne .) then  idadl&wv  =(dadl&wv0  =0 & dadl&wv  =1);
    if (diadl&wv0  ne . & diadl&wv  ne .) then  idiadl&wv =(diadl&wv0 =0 & diadl&wv =1);
    if (dhlth&wv0  ne . & dhlth&wv  ne .) then  idhlth&wv =(dhlth&wv0 =0 & dhlth&wv =1);
    if (proxyw&wv0 ne . & proxyw&wv ne .) then  iproxyw&wv=(proxyw&wv0=0 & proxyw&wv=1);
    if (cogim&wv0  ne . & cogim&wv  ne .) then  icogim&wv =(cogim&wv0 =0 & cogim&wv =1);

    if icancer&wv ne . then jcancer&wv = ((icancer&wv=1) | (ncancer&wv=1));
    if iheart&wv  ne . then jheart&wv  = ((iheart&wv=1)  | (nheart&wv=1));
    if istroke&wv ne . then jstroke&wv = ((istroke&wv=1) | (nstroke&wv=1));

    
   *Redefine Prevalence and J-incidence for;
   *fall incontinence and hip fracture     ;
    
    jfall&wv=fall&wv;
    jincont&wv=incont&wv;
    jhipfrc&wv=hipfrc&wv;

    fall&wv=max(fall&wv0,fall&wv);
    incont&wv=max(incont&wv0,incont&wv);
    hipfrc&wv=max(hipfrc&wv0,hipfrc&wv);


   label
      ihighbp&wv ="high bp incidence w&wv"
      ilung&wv   ="lung disease incidence w&wv"
      iarthrt&wv ="arthritis incidence w&wv"
      idiabet&wv ="diabetes incidence w&wv"
      icancer&wv ="cancer incidence w&wv"
      iheart&wv  ="heart dis/attack incidence w&wv"
      istroke&wv ="stroke incidence w&wv"
      icogn&wv   ="cognitive impair incidence w&wv"
      ipsych&wv  ="psychiatric prob incidence w&wv"
      ifall&wv   ="fall req treat incidence w&wv"
      ihipfrc&wv ="hip fracture incidence w&wv"
      iincont&wv ="incontinence incidence w&wv"
      idepres&wv ="depression incidence w&wv"

      idadl&wv ="ADLs incidence w&wv"
      idiadl&wv ="IADLs incidence w&wv"
      idhlth&wv ="fair/poor health incidence w&wv"
      iproxyw&wv ="proxy incidence w&wv"
      icogim&wv ="cog imp (educ adjust) incidence w&wv"

      jcancer&wv ="cancer incidence w&wv"
      jheart&wv  ="heart dis/attack incidence w&wv"
      jstroke&wv ="stroke incidence w&wv"

      jfall&wv   ="fall req treat incidence w&wv"
      jhipfrc&wv ="hip fracture incidence w&wv"
      jincont&wv ="incontinence incidence w&wv"
       ;
    
%mend;

   	     
data allwv;
    set allwv;

    %prev(1);
    %prev(2);
    %prev(3);

    %incid(2);
    %incid(3);
    
run;


/*
proc freq;
    tables
        ifall2*jfall2
        ihipfrc2*jhipfrc2
        iincont2*jincont2
        / list missing;
  */  




