/*****************************************************************/
/* FILE:        	wealthdata.sas                           */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Angela Merrill/Tiago Ribeiro             */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Code wealth data for analysis            */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/

data wealth;
    set track.track;
    if (study in(11,12,13));
    keep
        hhidpn hhid
        dsubhhw2 dsubhhw3 hhidpn
        biviewyr diviewyr fiviewyr
        biviewmo diviewmo fiviewmo
        ;    
run;

data mstat;
    set allwv;
    if (study in(11,12,13));
    keep
        hhidpn
        married1 married2 married3
        ;    
run;

   %merge(wealth,wealth,mstat,hhidpn);


%macro varlsthh(wave);
   condex&wave
      condfr&wave
      condgd&wave
      condpr&wave
      condvg&wave
      hoodex&wave
      hoodfr&wave
      hoodgd&wave
      hoodpr&wave
      hoodvg&wave
      duplex&wave
      mobhome&wave
      othhous&wave
      aptment&wave
      singfam&wave
      farm&wave
      farmlnd&wave
%mend;


   data w1income;
   set wave1f.w1income;
   keep hhid hrstinc1 hrscinc1;
run;

   %merge(wealth,wealth,w1income,hhid);

data w1assets;
    set local8.w1asta;
    keep hhid;
    keep %varlsthh(1);;

    noliq1=sum(of anhous1 anrlst1 antrns1 anbsns1 anothr1)-sum(of anmort1 an2mrt1 anloan1);

    liq1=sum(of anira1 anstck1 anchck1 ancd1 anbond1)-andebt1;  

    keep noliq1 liq1 v2wlth1 v2tinc1 dnhous1;

run;
   
%merge(wealth,wealth,w1assets,hhid);
   
   
data w2assets;
    set local8.w2asta;
    keep hhid dsubhh;
    rename dsubhh=dsubhhw2;
    keep %varlsthh(2);;
 
    noliq2=anhous2+anrlst2+antrns2+anbsns2+anothr2-anmort2-an2mrt2-anloan2;

    liq2=anira12+anira22+anira32+anstck2+anchck2+ancd2+anbond2-andebt2;  

    keep noliq2 liq2 v2wlth2 v2tinc2 dnhous2;

run;

   %merge(wealth,wealth,w2assets,hhid dsubhhw2);
   
data w3assets;
    set local8.w3asta;
    keep hhid fsubhh;
    rename fsubhh=dsubhhw3;
    keep %varlsthh(3);;

    noliq3=anhous3+anrlst3+antrns3+anbsns3+anothr3-anmort3-an2mrt3-anloan3;

    liq3=anira13+anira23+anira33+anstck3+anchck3+ancd3+anbond3-andebt3;  

    keep noliq3 liq3 v2wlth3 dnhous3;
    
run;

%merge(wealth,wealth,w3assets,hhid dsubhhw3,1);   
       
   ****************************************;
   * GET Stock price index created in get_stprice.sas;
   ****************************************;

data stprice;
    set stprice.stprice;
    run;
    
%merge(wealth,wealth,stprice,hhidpn,1);


   /* ---------------------------------------------------------------- */
   /* ---------------------------------------------------------------- */


/*
************************************************;
Compute New WEALTH variables 
Remove previous code when in no longer in use
************************************************;
*/


data wealth;
    set wealth;
    keep hhidpn
        biviewyr diviewyr fiviewyr
        biviewmo diviewmo fiviewmo
        v2wlth1 
        v2wlth2 
        v2wlth3 
        v2tinc1 hrstinc1 
        v2tinc2 
        married1 married2 married3
        noliq1 noliq2 noliq3 liq1 liq2 liq3

        dnhous1-dnhous3
        
        ret12ac ret23ac ret12ad ret23ad
        ret12bc ret23bc ret12bd ret23bd

        fspcom1 fspcom2 fspcom3
        rfspcom1 rfspcom2 rfspcom3
        
        ;    
       keep %varlsthh(1);;
       keep %varlsthh(2);;
       keep %varlsthh(3);;
 
    rename hrstinc1=vhtinc1;
run;

proc print data=wealth(obs=10);
proc means;    

data cpi1;
    set cpi.cpi;
    keep year month cpi97;
    year=year-1900;
    label cpi97='Consumer price index - base 97';
    rename
        year=biviewyr
        month=biviewmo
        cpi97=cpi1;
run;

data cpi2;
    set cpi.cpi;
    keep year month cpi97;
    year=year-1900;
    label cpi97='Consumer price index - base 97';
    rename
        year=diviewyr
        month=diviewmo
        cpi97=cpi2;
run;

data cpi3;
    set cpi.cpi;
    keep year month cpi97;
    year=year-1900;
    label cpi97='Consumer price index - base 97';
    rename
        year=fiviewyr
        month=fiviewmo
        cpi97=cpi3;
run;

%merge(wealth,wealth,cpi1,biviewyr biviewmo);
data wealth; set wealth; if in1;
    %merge(wealth,wealth,cpi2,diviewyr diviewmo);
data wealth; set wealth; if in1;
proc freq; tables diviewyr diviewmo /missing; where in2=0;
proc print; where cpi2=. and v2wlth2 ne .;
    %merge(wealth,wealth,cpi3,fiviewyr fiviewmo);
data wealth; set wealth; if in1;
proc freq; tables fiviewyr fiviewmo /missing; where in2=0;
proc print; where cpi3=. and v2wlth3 ne .;
data wealth; set wealth; drop in1 in2;
    
proc print data=wealth(obs=10);
    
    %let vw1=  v2wlth1   v2tinc1  vhtinc1  noliq1  liq1 ;
    %let cw1=  c2wlth1   c2tinc1  chtinc1 cnoliq1 cliq1 ;
    %let vw2=  v2wlth2   v2tinc2   noliq2  liq2 ;
    %let cw2=  c2wlth2   c2tinc2  cnoliq2 cliq2 ;
    %let vw3=  v2wlth3   noliq3   liq3;             
    %let cw3=  c2wlth3   cnoliq3  cliq3;             
    
data tmp1(keep=hhidpn &cw1 married1) tmp2(keep=hhidpn &cw2 married2) tmp3(keep=hhidpn &cw3 married3);
    set wealth;
    array vw1{*} &vw1;
    array cw1{*} &cw1;
    array vw2{*} &vw2;
    array cw2{*} &cw2;
    array vw3{*} &vw3;
    array cw3{*} &cw3;

    do i=1 to dim(cw1);
        cw1{i}=vw1{i}/cpi1*100;
        end;
    
    do i=1 to dim(cw2);
        cw2{i}=vw2{i}/cpi2*100;
        end;

    do i=1 to dim(cw3);
        cw3{i}=vw3{i}/cpi3*100;
        end;

    output tmp1;
    output tmp2;
    output tmp3;

run;


data tmp1;
    set tmp1;
    rename 
        c2wlth1=c_2w c2tinc1=c_2i  chtinc1=c_hi married1=married
        cliq1=c_2l cnoliq1=c_2n ;
*proc contents;
proc print data=tmp1(obs=10);
proc means;
    
data tmp2;
    set tmp2;
    rename 
        c2wlth2=c_2w c2tinc2=c_2i chtinc2=c_hi married2=married
        cliq2=c_2l cnoliq2=c_2n ;
*proc contents;
proc print data=tmp2(obs=10);
proc means;
    
data tmp3;
    set tmp3;
    rename 
        c2wlth3=c_2w c2tinc3=c_2i  chtinc3=c_hi married3=married
        cliq3=c_2l cnoliq3=c_2n ;
*proc contents;
proc print data=tmp3(obs=10);
proc means;


%let c_s= c_2w  c_2i  c_hi c_2l c_2n;
%let cps= cp2w  cp2i  cphi cp2l cp2n;

    
data tmp;
    set tmp1(in=ina) tmp2(in=inb) tmp3(in=inc);
    in1=ina; in2=inb; in3=inc;
    array c_s{*} &c_s;
    array cps{*} &cps;
    do i=1 to dim(c_s);
        cps{i}=c_s{i}/(married+1);
        end;
run;
proc contents;
proc print data=tmp(obs=10);
    
proc sort data=tmp;
    by married;
run;

%let q_sa= q_2wa  q_2ia  q_hia q_2la q_2na;
%let p_sa= p_2wa  p_2ia  p_hia p_2la p_2na;
                        
%let q_sb= q_2wb  q_2ib  q_hib q_2lb q_2nb;
%let p_sb= p_2wb  p_2ib  p_hib p_2lb p_2nb;
                        
%let q_sc= q_2wc  q_2ic  q_hic q_2lc q_2nc;
%let p_sc= p_2wc  p_2ic  p_hic p_2lc p_2nc;

/* AA */
proc rank group=4 ties=low data=tmp out=tmp;
    var    &c_s;
    ranks  &q_sa;
run;
proc rank group=100 ties=low data=tmp out=tmp;
    var    &c_s;
    ranks  &p_sa;
run;

/* BB */
proc rank group=4 ties=low data=tmp out=tmp;
    by married;
    var    &c_s;
    ranks  &q_sb;
run;

proc rank group=100 ties=low data=tmp out=tmp;
    by married;
    var    &c_s;
    ranks  &p_sb;
run;

/* CC */
proc rank group=4 ties=low data=tmp out=tmp;
    var    &cps;
    ranks  &q_sc;
run;
proc rank group=100 ties=low data=tmp out=tmp;
    var    &cps;
    ranks  &p_sc;
run;


%let varlst= &q_sa &p_sa &q_sb &p_sb &q_sc &p_sc;

data tmp1 tmp2 tmp3;
    set tmp;
    array vars{*} &varlst;
    
    do i=1 to dim(vars);
        vars{i}=vars{i}+1;
        end;

    if in1 then output tmp1;
    if in2 then output tmp2;
    if in3 then output tmp3;
run;
*proc contents;
        proc print data=tmp1(obs=10);
        proc print data=tmp2(obs=10);
        proc print data=tmp3(obs=10);
            
%let varlst2=&varlst &c_s;

%macro ren(list,po);
    %let wrd=%scan(&list,1);
    %let n=1;
    %do %until(&wrd eq %str());
        %let a=%substr(&wrd,1,2);
        %let b=%substr(&wrd,3,1);
        %let c=%substr(&wrd,4,1);
        %let d=%substr(&wrd,5,1);

        %if &c eq w %then %let c=Wealth;
        %if &c eq i %then %let c=Income;
        %if &c eq l %then %let c=Liq W;
        %if &c eq n %then %let c=Non-Liq W;

        %if &a eq c_ %then %let a=97 dol;
        %if &a eq q_ %then %let a=quart;
        %if &a eq p_ %then %let a=perc;

        %if &d eq a %then %let d=hh;
        %if &d eq b %then %let d=by marstat;
        %if &d eq c %then %let d=per cap;
        
        label &wrd="&c &a &d W&po (V.&b)";
        rename &wrd=&wrd.&po;

        %let n=%eval(&n+1);
        %let wrd=%scan(&list,&n);
        %end;
    %mend;

data tmp1;
    set tmp1;
    keep hhidpn cpi1 &varlst2;
    %ren(&varlst2,1);
run;
*proc contents;

data tmp2;
    set tmp2;
    keep hhidpn cpi2 &varlst2;
    %ren(&varlst2,2);
run;
*proc contents;

data tmp3;
    set tmp3;
    keep hhidpn cpi3 &varlst2;
    %ren(&varlst2,3);
run;
*proc contents;

%merge(tmp,tmp1,tmp2,hhidpn);
%merge(tmp,tmp,tmp3,hhidpn);
%merge(wealth,wealth,tmp,hhidpn);

proc print data=tmp(obs=10);
proc contents data=wealth;

data wealth;
    set wealth;
    drop 
        biviewyr diviewyr fiviewyr
        biviewmo diviewmo fiviewmo
/*
        v2wlth1 
        v2wlth2 
        v2wlth3 
        v2tinc1  hrstinc1 
        v2tinc2 
        vhtinc1
        */
        married1 married2 married3
/*        noliq1 noliq2 noliq3 liq1 liq2 liq3*/
        in1 in2
        c_hi2 
        c_hi3 
        p_2ia3
        p_2ib3
        p_2ic3
        p_hia2
        p_hia3
        p_hib2
        p_hib3
        p_hic2
        p_hic3
        q_2ia3
        q_2ib3
        q_2ic3
        q_hia2
        q_hia3
        q_hib2
        q_hib3
        q_hic2
        q_hic3
        ;

proc contents data=wealth;

proc means;
proc means;
    var c_2w1 c_2w2 c_2w3;

proc corr;    var p_2wa1 p_2wb1 p_2wc1;
proc corr;    var p_2wa2 p_2wb2 p_2wc2;
proc corr;    var p_2wa3 p_2wb3 p_2wc3;
    
proc freq;
    tables q_2wa1*q_2wb1*q_2wc1 /list missing;
    tables q_2wa2*q_2wb2*q_2wc2 /list missing;
    tables q_2wa3*q_2wb3*q_2wc3 /list missing;

/* END WEALTH VARIABLES */

