/*****************************************************************/
/* FILE:        	impcat_macro.sas                         */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Macro for categorical asset imputation   */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/

%macro impcat(data,impv,impvn,mapd,cntrlv,seed); 
/* Count vars */
    %let ni=0;
    %let v=0;
    %do %while(&v ne %str());
        %let ni=%eval(&ni+1);
        %let v=%scan(&impv,&ni);
        %end;        
    %let ni=%eval(&ni-1);
    %let nc=0;
    %let v=0;
    %do %while(&v ne %str());
        %let nc=%eval(&nc+1);
        %let v=%scan(&cntrlv,&nc);
        %end;        
    %let nc=%eval(&nc-1);
    %let nt=%eval(&ni+&nc);

    data _local1;
        set &data;
        keep &cntrlv &impv;
        order0=_n_;
        keep order0;
    run;


    %do i=1 %to &ni; 
        %let v=%scan(&impv,&i);
    
        data cat;
            set %scan(&mapd,&i,%str( ));  
            _flag&i=((sum(of _all_)-&v)>1);
            keep &v _flag&i;
        run;
        proc sort data=_local1; by &v;
        data _local1;
            merge _local1(in=in1) cat; 
            by &v;
            if in1;
        run;
        
        %end;        


    data _local1;
        set _local1;
        dono=(sum(of _flag:)=0);
        drop _flag:;
    run;
    
    *proc contents data=_local1;
    proc sort     data=_local1; by order0;
    *proc print    data=_local1(obs=10);

        
    %let vars=&cntrlv &impv;
    %if &nt>1 %then %do;
        %let tablst=%scan(&vars,1)*;
        %do i=2 %to %eval(&nt-1);
            %let tablst=&tablst%scan(&vars,&i)*;
            %end;
        %let tablst=&tablst%scan(&vars,&nt);
        %end;
    %if &nt=1 %then %do;
        %let tablst=%scan(&vars,1);
        %end;
    %put &tablst;

    proc freq noprint;
        where dono=1;
        tables &tablst / missing sparse list out=_local2(drop=percent);
    run;
    
    *proc contents;
    
    proc iml;
        * Read unimputed data;
        use _local1 var {&vars dono order0};
        read all var {&vars} into data0;
        read all var {dono} into dono;
        read all var {order0} into order0;
        tablei0=data0[loc(dono=0),];

        * Read donor frequency table;
        use _local2 var _all_;
        read all var _all_ into table0;

        %do i=1 %to &ni;
            use %scan(&mapd,&i,%str( )) var _all_;
            read all var _all_ into cat&i;
            *print cat&i;
            %end;
        
        dim=j(1,&nt,0);
        n=0;
        do i=&nt to 1 by -1;
            n=n+1;
            h=unique(table0[,i]);
            dim[1,n]=ncol(h);
            end;
        
        config=j(2,&nt*(&nt-1)/2,0);
        n=0;
        do i=1 to &nt;
            do j=i+1 to &nt;
                n=n+1;
                config[1,n]=i;
                config[2,n]=j;
                end;
            end;
        *print dim;
        *print config;

        fitd=table0[,&nt+1];
        fit0=fitd;
        ndono=fitd[+,];
        maxiter=50;
        crit=j(1,maxiter,0);
        iter=0;
        crit0=1;
        
        do while(crit0>1E-8 & iter<maxiter);
            iter=iter+1;
            *print iter;

            call ipf(fit1,status,dim,fit0,config,j(nrow(fit0),1,1));

            if iter=1 then do;
                p1=fit1/fit1[+,];
                end;
            else do;
                p0=p1;
                p1=fit1/fit1[+,];
                crit0=sqrt(ssq(p1-p0));
                *crit[1,iter-1]=crit0;
            end;
        
            fit0=fitd;
            do nob=1 to nrow(tablei0);
                obs=tablei0[nob,];
                h=j(nrow(fit1),1,1);
                %if &nc>0 %then %do;
                    %do i=1 %to &nc;
                        h1=j(nrow(table0),1,0);
                        h1[loc(table0[,&i]=obs[&i]),]=1;
                        h=h1#h;
                        %end;
                    %end;
                %do i=1 %to &ni;
                    %let i1=%eval(&i+&nc);
                    ncat=ncol(cat&i)-1;
                    h1=t(cat&i[loc(cat&i[,ncat+1]=obs[&i1]),1:ncat]);
                    h2=table0[,&i1];
                    h3=unique(h2);
                    h4=j(nrow(h2),1,0);
                    do j=1 to ncol(h3);
                        h4[loc(h2=h3[j]),]=j;
                        end;
                    *print ncat h1 h3;
                    h1=h1[h4,];
                    h=h1#h;
                    %end;
                h0=h#fit1;
                if h0[+,]=0 then do;
                    h=h/h[+,];
                    end;
                else do;
                    h=h0/h0[+,];
                    end;
                fit0=fit0+h;
                end;
            end;

        crit=crit[1,1:iter-1];
        res=table0||fit1||fit0;
        sres=res[+,];
        print iter;

        * Impute based on fitted table *;

        tablei1=j(nrow(tablei0),ncol(tablei0),-1);
        do nob=1 to nrow(tablei0);
            obs=tablei0[nob,];
            h=j(nrow(fit1),1,1);
            %if &nc>0 %then %do;
                %do i=1 %to &nc;
                    h1=j(nrow(table0),1,0);
                    h1[loc(table0[,&i]=obs[&i]),]=1;
                    h=h1#h;
                    %end;
                %end;
            %do i=1 %to &ni;
                %let i1=%eval(&i+&nc);
                ncat=ncol(cat&i)-1;
                h1=t(cat&i[loc(cat&i[,ncat+1]=obs[&i1]),1:ncat]);
                h2=table0[,&i1];
                h3=unique(h2);
                h4=j(nrow(h2),1,0);
                do j=1 to ncol(h3);
                    h4[loc(h2=h3[j]),]=j;
                    end;
                *print ncat h1 h3;
                h1=h1[h4,];
                h=h1#h;
                %end;
            loc1=loc(h>0);
            h=h#fit1;
            h=h/h[+,];
            cdf=cusum(h[loc1,]);
            r=uniform(&seed);
            loc2=loc(cdf>r);
            tablei1[nob,]=table0[loc1[loc2[1,1]],1:&nt];
            end;

        *final=tablei0||tablei1;
        *print final;

        finald=data0[loc(dono=1),]||order0[loc(dono=1),];
        finali=tablei1||order0[loc(dono=0),];
        final=finald//finali;

        h=final;
        final[rank(final[,ncol(final)]),]=h;
        *print final;
        final=final[,1:(ncol(final)-1)];

        vnames={&cntrlv &impvn};
        create _local3 from final[colname=vnames];
        append from final;
    run;

    *proc contents data=_local3;
    data _local3;
        set _local3;
        drop &cntrlv;
    run;
    data &data;
        set &data;
        set _local3;
    run; 

    %do i=1 %to &ni;
        %let v=%scan(&impv,&i);
        %let vn=%scan(&impvn,&i);

        title 'Raw marginals';
        proc freq;
            tables &v /missing;
        run;
        title 'Donors marginals';
        proc freq;
            where &v=&vn;
            tables &vn /missing;
        run;
        title 'Imputed marginals';
        proc freq;
            where &v ne &vn;
            tables &vn /missing;
        run;
        title 'Donors + imputed marginals';
        proc freq;
            tables &vn /missing;
        run;
        title '';
        %end;    
%mend;
