/*****************************************************************/
/* FILE:        	monthdata.sas                            */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Impute months at risk for deceased resp  */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
%include '~/ribeiro/datagen/header.inc';
options ls=100;

/***********************************************************/
/***********************************************************/
/***********************************************************/

proc contents data=track.track;

data track;
    set track.track;
    keep
        age
        hhidpn
        biviewyr
        biviewmo
        diviewyr
        diviewmo
        fiviewyr
        fiviewmo
        month12
        month23
        tdied2
        tdied3
        birthyr
        birthmo
        inw1 inw2 inw3
        clean eligible
        exitw2 exitw3
        modie2 yrdie2
        modie3 yrdie3
        female
        race1 race2
        ;
    
    black=(race2=2);
    if race2=0 then black=.;
    hispan=(race1=1);
    if race1=0 then hispan=.;
    keep black hispan;

    if yrdie3=9998 then yrdie3=.;
    if modie3>12 then modie3=.;

    month1=12*biviewyr+biviewmo;
    month2=12*diviewyr+diviewmo;
    month3=12*fiviewyr+fiviewmo;
    monthd2=12*(yrdie2-1900)+modie2;
    monthd3=12*(yrdie3-1900)+modie3;

    agem1=(biviewyr+1900-birthyr)*12+biviewmo-birthmo;

    keep month1 month2 month3 monthd2 monthd3 agem1;
run;

proc freq; tables month1-month3; run;
proc freq; tables Tdied2*month1*month2 tdied3*month2*month3 / nocol nofreq nopercent; run;


proc freq;
    tables
        clean*eligible
        age*clean*eligible
        birthyr*clean*eligible
        tdied2*exitw2*clean*eligible
        tdied2*exitw2*diviewyr
        tdied2*exitw2*diviewmo
        tdied2*exitw2*yrdie2
        tdied2*exitw2*modie2

        tdied3*exitw3*clean*eligible
        tdied3*exitw3*fiviewyr
        tdied3*exitw3*fiviewmo
        tdied3*exitw3*yrdie3
        tdied3*exitw3*modie3
        hispan black         
        / missing list;
run;


data tmp;
    set track;
    if inw1;    
run;

proc means;
class tdied2;
var month12;
run;
proc means;
class tdied3;
var month23;
run;

proc sort; by tdied2;
proc rank ties=low groups=3;
by tdied2;
var month1;
ranks pm1;
run;

proc sort; by tdied2 pm1;
proc reg;
by tdied2 pm1;
model month2=month1;
model month12=month1;

proc sort; by tdied3;
proc rank ties=low groups=3;
by tdied3;
var month2;
ranks pm2;
run;

proc sort; by tdied3 pm2;
proc reg;
by tdied3 pm2;
model month3=month2;
model month23=month2;



/* Send Data to Matlab */

data _null_;
set tmp;
file 'months.csv';
array miss{*} month1 month2 month3 tdied2 tdied3 agem1 monthd2 monthd3 ;
do i=1 to dim(miss);
if miss{i}=. then miss{i}=-9;
end;
put hhidpn ','  month1 ',' month2 ',' month3 ',' tdied2 ',' tdied3 ','
agem1 ',' monthd2 ',' monthd3 ;
run;

/* Execute  Matlab program */
x matlab < months.m > months.out ;

/* Get Data from Matlab */

filename f1 'm_impted.csv';
data matlab;
    infile f1 dsd;
    input hhidpn m1 m2 m3 m12 m23 md2 md3 agem2 agem3 g1 g2;
    
run;

proc means;
proc contents;

data tmp;
    set tmp;
    rename month1=r_m1;
    rename month2=r_m2;
    rename month3=r_m3;
    rename month12=r_m12;
    rename month23=r_m23;
    rename monthd2=r_md2;
    rename monthd3=r_md3;
run;
    

%merge(tmp,tmp,matlab,hhidpn);

proc freq;
where tdied2=1;
tables md2;
proc freq;
where tdied3=1;
tables md3;
run;



data tmp;
    set tmp;
    
    array miss{*} m3 m23 md2 md3 agem3;
    do i=1 to dim(miss);
        if miss{i}<=0 then miss{i}=.;
        end;
    drop i;
    
    flagm2=(r_m2 ne m2);
    flagm3=(r_m3 ne m3);
    flagm12=(r_m12 ne m12);
    flagm23=(r_m23 ne m23);
    flagmd2=(r_md2 ne md2);
    flagmd3=(r_md3 ne md3);

    rename
        m1=months1
        m2=months2
        m3=months3
        m12=month12
        m23=month23
        md2=monthd2
        md3=monthd3;
    
    agedie2=md2-((birthyr-1900)*12+birthmo);
    agedie3=md3-((birthyr-1900)*12+birthmo);
run;

data tmp;
    set tmp;
      
    label

        r_m1='Date of 1st iview in months - no imp'
        r_m2='Date of 2nd iview in months - no imp'
        r_m3='Date of 3rd iview in months - no imp'
        r_m12 = 'Months between w1 and w2 - no imp'
        r_m23 = 'Months between w2 and w3 - no imp'
        r_md2='Date of death w2 in months - no imp'
        r_md3='Date of death w3 in months - no imp'

        flagm2='Imputation flag - months2'
        flagm3='Imputation flag - months3'
        flagm12='Imputation flag - month12'
        flagm23='Imputation flag - month23'
        flagmd2='Imputation flag - monthd2'
        flagmd3='Imputation flag - monthd3'

        month12 = 'Months between w1 and w2'
        month23 = 'Months between w2 and w3'
        months1='Date of 1st iview in months'
        months2='Date of 2nd iview in months'
        months3='Date of 3rd iview in months'
        monthd2='Date of death w2 in months'
        monthd3='Date of death w3 in months'
        agem1='Age at 1st iview in months'
        agem2='Age at 2nd iview in months'
        agem3='Age at 3rd iview in months'
        agedie2='Age of death in months'
        agedie3='Age of death in months';
run;

    
proc means;
    class biviewyr;
    var biviewmo;

proc means;
    class diviewyr;
    var diviewmo;

proc means;
    class fiviewyr;
    var fiviewmo;

proc means;
    where clean;
    var months1 months2 months3;

proc means;
    where clean; 
    var months1 months2 months3;

proc means;
    where clean and eligible; 
    class tdied2 tdied3;
    var months1 months2 months3;

proc means;
    where clean and eligible; 
    class tdied2 tdied3;
    var months1 months2 months3;
    
proc univariate;
       where clean; 
    var months1 months2 months3;

proc univariate;
       where clean and eligible; 
    var months1 months2 months3;

proc sort; by tdied2 tdied3;
    
proc univariate;
       where clean; 
    by tdied2;
    var months2;
    
proc univariate;
       where clean and eligible; 
    by tdied2;
    var months2;

proc univariate;
       where clean; 
    by tdied2 tdied3;
    var months3;
    

proc univariate;
       where clean and eligible; 
    by tdied2 tdied3;
    var months3;

proc contents;
proc means;

data tmp;
set tmp;
keep
 AGEDIE2
 AGEDIE3
 AGEM1  
 AGEM2  
 AGEM3  
 FLAGM2 
 FLAGM3 
 FLAGM12
 FLAGM23
 FLAGMD2
 FLAGMD3
 G1     
 G2     
 HHIDPN 
 MONTH12
 MONTH23
 MONTHD2
 MONTHD3
 MONTHS1
 MONTHS2
 MONTHS3
 R_M1   
 R_M2   
 R_M3   
 R_M12  
 R_M23  
 R_MD2  
 R_MD3  
 TDIED2 
 TDIED3 ;
run;

proc means;

data local.monthdta;
    set tmp;
    run;
    





